import re

from click import secho
import requests


URL = 'https://www.bikeseoul.com/app/station/getStationRealtimeStatus.do'

DISTRICTS = [
    {  # Songpa-gu
        'code': 23,
        'interested': set([
            '1210. 롯데월드타워(잠실역2번출구 쪽)',
            '1231. 잠실역 6번출구',
        ])
    },
    {  # Gangnam-gu
        'code': 33,
        'interested': set([
            '2316. 삼성역 8번출구',
            '2322. 삼성역 3번 출구',
            '2348. 포스코사거리(기업은행)',
            '2355. 삼성역 5~6번 출구 사이',
        ])
    },
]

def command():
    for name, count in query(DISTRICTS):
        color = ('red' if count == 0 else 'green')
        secho(f'({count})', fg=color, nl=False)
        secho(f'- {name}')


def query(districts):
    for d in districts:
        payload = {'stationGrpSeq': d['code']}
        response = requests.post(URL, data=payload)
        rows = response.json()['realtimeList']
        for row in rows:
            name = row['stationName'].strip()
            if name in d['interested']:
                count = int(row['parkingBikeTotCnt'])
                yield (name, count)



import os
import re
import sys
import webbrowser

import click
import pyperclip
import requests


LOOKUPS = [
    'http://www.google.com/search?tbm=isch&q=%s',
    'http://englishdictionary.naver.com/#/search?query=%s',
    'http://www.thesaurus.com/browse/%s',
    'https://www.vocabulary.com/dictionary/%s',
    'http://endic.naver.com/search.nhn?sLn=kr&query=%s',
]


@click.option('--anki-media', envvar='ANKI_MEDIA')
@click.option('-q', '--quiet', '--no-lookup', is_flag=True)
@click.argument('words', nargs=-1)
def command(anki_media, no_lookup, words):
    filenames = []
    for w in words:
        word = w.lower()
        filename = '%s.mp3' % word
        filenames.append((word, filename))
        filepath = os.path.join(anki_media, filename)
        bytes_ = voice_of(word)

        if not no_lookup:
            lookup(word)

        save(filepath, bytes_)
        play(filepath)

    content = '\n'.join('%s [sound:%s]' % (w, fn) for w, fn in filenames)
    pyperclip.copy(content)
    print(content)


def lookup(word):
    for l in LOOKUPS:
        webbrowser.open_new_tab(l % word)


def voice_of(word):
    url = 'http://endic.naver.com/search.nhn?sLn=en&query={}'.format(word)
    page_source = make_request(url).decode('utf-8')

    mo = re.search(r'playlist="([^"]+)"', page_source)
    if mo:
        voice_url = mo.group(1)
        return make_request(voice_url)
    else:
        errexit("Unable to find voice for '%s'" % word)


def make_request(url):
    response = requests.get(url)
    return response.content


def save(filepath, bytes_):
    with open(filepath, 'wb') as f:
        f.write(bytes_)


def play(filepath):
    cmd = "( afplay '%s' & )" % filepath
    os.system(cmd)


def errexit(message):
    print(message, file=sys.stderr)
    sys.exit(1)



from importlib import import_module
from pkgutil import iter_modules


def build(cli, path, package):
    """Build CLI dynamically based on the package structure.
    """
    for _, name, ispkg in iter_modules(path):
        module = import_module(f'.{name}', package)
        if ispkg:
            build(cli.group(name)(module.group),
                  module.__path__,
                  module.__package__)
        else:
            cli.command(name)(module.command)



import click

from yhy import commands


@click.group()
def cli():
    pass


commands.build(cli,
               commands.__path__,
               commands.__package__)


if __name__ == '__main__':
    cli()



import click

from yhy import require
from yhy.core.img import clipboard_img, save


@click.argument('path', type=click.Path(exists=False))
def command(path):
    require.directory(path)
    img = clipboard_img()
    save(img, path)



import click
from PIL import ImageGrab


def clipboard_img():
    img = ImageGrab.grabclipboard()
    if img is None:
        raise click.UsageError('Clipboard does not contain image data')
    else:
        return img


def save(img, path):
    img.save(path)



import ast
import re
from setuptools import find_packages, setup


def extract_version(content):
    m = re.search(r'__version__\s+=\s+(.*)', content)
    s = m.group(1)
    return str(ast.literal_eval(s))


with open('yhy/__init__.py', 'rb') as f:
    content = f.read().decode('utf-8')
    version = extract_version(content)


setup(
    name='yhy',
    version=version,
    description='Personalized CLI',
    keywords='automation cli anki',
    url='https://github.com/yeonghoey/yhy',

    author='Yeongho Kim',
    author_email='yeonghoey@gmail.com',

    packages=find_packages(),

    entry_points={
        'console_scripts': [
            'yhy=yhy.__main__:cli',
        ]
    },

    install_requires=[
        'Click',
        'pillow',
        'pyperclip',
        'requests'
    ],

    classifiers=[
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python :: 3.6',
    ],
)
